#include "stdafx.h"
#include "config.h"

/**************************
Storing settings.

Here settings refer to any information that needs to be
remembered across sessions, like window positions and such.
foobar2000 provides configuration variables to do this,
which come in two different flavors: private and public.
Private configuration variables are derived from cfg_var in
the pfc library; they can only be accessed in the component
that declares them. Public configuration variables are 
dervided from config_object; they can be accessed
from any component. Public configuration variables can be
used from any thread, since they have builtin synchronization,
whereas access to private configuration variables has to be
synchronized by the component where necessary.

We won't use threads in this component, and we don't want
our settings to be publicly available, so we will use the
cfg_var subclasses from the SDK.

Note: Variables are internally identified by a GUID you
pass as the first parameter to the constructor. The second
parameter of the contructor is the default value. Some types
of configuration variables have an implicit default value,
so their constructor takes only one parameter.
**************************/


// We will provide a window that can be toggled on and off
// by the user, so here come the settings for this.

// boolean variable
// Stores whether the window is enabled.
// {367F752A-B175-4334-80E6-A6FDBEE3C9FA}
static const GUID guid_cfg_enabled = { 0x367f752a, 0xb175, 0x4334, { 0x80, 0xe6, 0xa6, 0xfd, 0xbe, 0xe3, 0xc9, 0xfa } };
cfg_bool cfg_enabled(guid_cfg_enabled, false);

// {C223801B-F247-40f8-BBDA-AA5E27A5D227}
static const GUID guid_cfg_branch = { 0xc223801b, 0xf247, 0x40f8, { 0xbb, 0xda, 0xaa, 0x5e, 0x27, 0xa5, 0xd2, 0x27 } };
static advconfig_branch_factory cfg_branch( "Stop after current album", guid_cfg_branch, advconfig_entry::guid_branch_playback, 0 );

// {7FBF948B-1C9F-477c-B228-EF0A228E9546}
static const GUID guid_cfg_only_stop_once = { 0x7fbf948b, 0x1c9f, 0x477c, { 0xb2, 0x28, 0xef, 0xa, 0x22, 0x8e, 0x95, 0x46 } };
advconfig_checkbox_factory_t<false> cfg_only_stop_once( "Only stop once", guid_cfg_only_stop_once, guid_cfg_branch, 0, false );

// {26FEDEEA-0527-4a9a-8422-B078C1A56254}
static const GUID guid_cfg_album_pattern = { 0x26fedeea, 0x527, 0x4a9a, { 0x84, 0x22, 0xb0, 0x78, 0xc1, 0xa5, 0x62, 0x54 } };
advconfig_string_factory cfg_album_pattern( "Album pattern", guid_cfg_album_pattern, guid_cfg_branch, 0, "%album artist% | %album% | %date% | %directoryname%" );
